package javax.swing.plaf.metal;

import java.awt.Dimension;
import java.awt.Component;
import java.awt.Insets;
import javax.swing.JPanel;
import java.awt.Graphics;
import javax.swing.UIManager;
import javax.swing.DefaultButtonModel;
import javax.swing.Icon;
import javax.swing.CellRendererPane;
import javax.swing.JList;
import javax.swing.JComboBox;
import javax.swing.JButton;

public class MetalComboBoxButton extends JButton
{
    protected JComboBox comboBox;
    protected JList listBox;
    protected CellRendererPane rendererPane;
    protected Icon comboIcon;
    protected boolean iconOnly;
    
    public final JComboBox getComboBox() {
        return this.comboBox;
    }
    
    public final void setComboBox(JComboBox comboBox) {
        this.comboBox = comboBox;
    }
    
    public final Icon getComboIcon() {
        return this.comboIcon;
    }
    
    public final void setComboIcon(Icon comboIcon) {
        this.comboIcon = comboIcon;
    }
    
    public final boolean isIconOnly() {
        return this.iconOnly;
    }
    
    public final void setIconOnly(boolean iconOnly) {
        this.iconOnly = iconOnly;
    }
    
    MetalComboBoxButton() {
        super("");
        this.iconOnly = false;
        this.setModel(new DefaultButtonModel() {
            @Override
            public void setArmed(boolean b) {
                super.setArmed(this.isPressed() || b);
            }
        });
    }
    
    public MetalComboBoxButton(JComboBox comboBox, Icon comboIcon, CellRendererPane rendererPane, JList listBox) {
        this();
        this.comboBox = comboBox;
        this.comboIcon = comboIcon;
        this.rendererPane = rendererPane;
        this.listBox = listBox;
        this.setEnabled(this.comboBox.isEnabled());
    }
    
    public MetalComboBoxButton(JComboBox comboBox, Icon icon, boolean iconOnly, CellRendererPane cellRendererPane, JList list) {
        this(comboBox, icon, cellRendererPane, list);
        this.iconOnly = iconOnly;
    }
    
    @Override
    public boolean isFocusTraversable() {
        return false;
    }
    
    @Override
    public void setEnabled(boolean enabled) {
        super.setEnabled(enabled);
        if (enabled) {
            this.setBackground(this.comboBox.getBackground());
            this.setForeground(this.comboBox.getForeground());
        }
        else {
            this.setBackground(UIManager.getColor("ComboBox.disabledBackground"));
            this.setForeground(UIManager.getColor("ComboBox.disabledForeground"));
        }
    }
    
    public void paintComponent(Graphics g) {
        int leftToRight = MetalUtils.isLeftToRight(this.comboBox);
        super.paintComponent(g);
        Insets insets = this.getInsets();
        int n = this.getWidth() - (insets.left + insets.right);
        int n2 = this.getHeight() - (insets.top + insets.bottom);
        if (n2 <= 0 || n <= 0) {
            return;
        }
        int left = insets.left;
        int top = insets.top;
        int n3 = left + (n - 1);
        int n4 = top + (n2 - 1);
        int iconWidth = 0;
        left = (leftToRight ? n3 : left);
        if (this.comboIcon != null) {
            iconWidth = this.comboIcon.getIconWidth();
            int iconHeight = this.comboIcon.getIconHeight();
            int n5;
            int n6;
            if (this.iconOnly) {
                n5 = this.getWidth() / 2 - iconWidth / 2;
                n6 = this.getHeight() / 2 - iconHeight / 2;
            }
            else {
                if (!(leftToRight == 0)) {
                    n5 = left + (n - 1) - iconWidth;
                }
                else {
                    n5 = left;
                }
                n6 = top + (n4 - top) / 2 - iconHeight / 2;
            }
            this.comboIcon.paintIcon(this, g, n5, n6);
            if (this.comboBox.hasFocus() && (!MetalLookAndFeel.usingOcean() || this.comboBox.isEditable())) {
                g.setColor(MetalLookAndFeel.getFocusColor());
                g.drawRect(left - 1, top - 1, n + 3, n2 + 1);
            }
        }
        if (MetalLookAndFeel.usingOcean()) {
            return;
        }
        if (!this.iconOnly && this.comboBox != null) {
            Component listCellRendererComponent = this.comboBox.getRenderer().getListCellRendererComponent(this.listBox, this.comboBox.getSelectedItem(), -1, this.getModel().isPressed(), false);
            listCellRendererComponent.setFont(this.rendererPane.getFont());
            if (this.model.isArmed() && this.model.isPressed()) {
                if (this.isOpaque()) {
                    listCellRendererComponent.setBackground(UIManager.getColor("Button.select"));
                }
                listCellRendererComponent.setForeground(this.comboBox.getForeground());
            }
            else if (!this.comboBox.isEnabled()) {
                if (this.isOpaque()) {
                    listCellRendererComponent.setBackground(UIManager.getColor("ComboBox.disabledBackground"));
                }
                listCellRendererComponent.setForeground(UIManager.getColor("ComboBox.disabledForeground"));
            }
            else {
                listCellRendererComponent.setForeground(this.comboBox.getForeground());
                listCellRendererComponent.setBackground(this.comboBox.getBackground());
            }
            int n7 = n - (insets.right + iconWidth);
            boolean n8 = false;
            if ((listCellRendererComponent instanceof JPanel)) {
                n8 = true;
            }
            if (!(leftToRight == 0)) {
                this.rendererPane.paintComponent(g, listCellRendererComponent, this, left, top, n7, n2, (boolean)n8);
            }
            else {
                this.rendererPane.paintComponent(g, listCellRendererComponent, this, left + iconWidth, top, n7, n2, (boolean)n8);
            }
        }
        return;
    }
    
    @Override
    public Dimension getMinimumSize() {
        Dimension dimension = new Dimension();
        Insets insets = this.getInsets();
        dimension.width = insets.left + this.getComboIcon().getIconWidth() + insets.right;
        dimension.height = insets.bottom + this.getComboIcon().getIconHeight() + insets.top;
        return dimension;
    }
}
